==> gcc-java-4.5.4.tar.bz2: gcc-4.5.4/libjava/classpath/tools/gnu/classpath/tools/gjdoc/expr/ConstantLong.java <==
/* gnu.classpath.tools.gjdoc.expr.ConstantLong
   Copyright (C) 2004 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.
 
GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA. */

package gnu.classpath.tools.gjdoc.expr;

class ConstantLong
   extends ConstantExpression
{
   private long value;

   public ConstantLong(String stringValue)
   {
      if ('l' == Character.toLowerCase(stringValue.charAt(stringValue.length() - 1))) {
         this.value = Evaluator.parseLong(stringValue.substring(0, stringValue.length() - 1));
      }
      else {
         this.value = Evaluator.parseInt(stringValue.substring(0, stringValue.length() - 1));
      }
   }

   public ConstantLong(long longValue)
   {
      this.value = longValue;
   }

   public Type getType()
   {
      return Type.LONG;
   }

   public Number asNumber()
   {
      return new Long(value);
   }

   public boolean isNumber()
   {
      return true;
   }

   public Object asObject()
   {
      return asNumber();
   }

   public String toString()
   {
      return Long.toString(value);
   }
}

==> gcc-java-4.6.3.tar.bz2: gcc-4.6.3/libjava/classpath/tools/gnu/classpath/tools/gjdoc/expr/ConstantLong.java <==
/* gnu.classpath.tools.gjdoc.expr.ConstantLong
   Copyright (C) 2004 Free Software Foundation, Inc.

This file is part of GNU Classpath.

GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with GNU Classpath; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version. */

package gnu.classpath.tools.gjdoc.expr;

class ConstantLong
   extends ConstantExpression
{
   private long value;

   public ConstantLong(String stringValue)
   {
      if ('l' == Character.toLowerCase(stringValue.charAt(stringValue.length() - 1))) {
         this.value = Evaluator.parseLong(stringValue.substring(0, stringValue.length() - 1));
      }
      else {
         this.value = Evaluator.parseInt(stringValue.substring(0, stringValue.length() - 1));
      }
   }

   public ConstantLong(long longValue)
   {
      this.value = longValue;
   }

   public Type getType()
   {
      return Type.LONG;
   }

   public Number asNumber()
   {
      return new Long(value);
   }

   public boolean isNumber()
   {
      return true;
   }

   public Object asObject()
   {
      return asNumber();
   }

   public String toString()
   {
      return Long.toString(value);
   }
}
